﻿using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.Data.Entity;
using System.Linq;
using System.Text;
using System.Threading.Tasks;


namespace NationalTheatreBrnoEF
{
    class Program
    {
        static void Main(string[] args)
        {
            //CreateSampleData();
            
            Console.Write("Zadejte nazev predstaveni: ");
            string input = Console.ReadLine();

            var results = FindPerformanceByName(input);

            Console.WriteLine("Vysledky vyhledavani:");
            foreach(Performance p in results)
            {
                Console.WriteLine(p.Name);
            }

            Console.ReadKey();

            Console.WriteLine("Performances count:");
            int perfCount = CountPerformances("Mahen");
            Console.WriteLine(perfCount);

            Console.ReadKey();
        }

        static void CreateSampleData()
        {
            using (NationatTheatreDBContext db = new NationatTheatreDBContext())
            {                
                Theatre mahen = new Theatre();
                mahen.Name = "Mahenovo divadlo";
                mahen.Address = "Malinovského nám. 1";
                mahen.Phone = "789456123";
                mahen.Capacity = 350;

                db.Theatres.Add(mahen);
                db.SaveChanges();

                Performance p = new Performance();
                p.Name = "Králova řeč";
                p.Price = 400;
                p.Start = new DateTime(2014, 4, 22);
                p.Theatre = mahen;

                db.Performances.Add(p);

                Performance p2 = new Performance();
                p2.Name = "Jak je důležité míti Filipa";
                p2.Price = 350;
                p2.Start = new DateTime(2014, 4, 25);
                p2.Theatre = mahen;

                db.Performances.Add(p2);
                db.SaveChanges();
            }
        }

        public static List<Performance> FindPerformanceByName(string substr)
        {
            List<Performance> p = null;
            using (NationatTheatreDBContext db = new NationatTheatreDBContext())
            {                
                p = (from a in db.Performances
                     where a.Name.Contains(substr)
                     select a).ToList();                

            }
            return p;
        }

        static int CountPerformances(string theatreName)
        {
            int perfCount = 0;
            using (NationatTheatreDBContext db = new NationatTheatreDBContext())
            {               
                perfCount = db.Performances.Count();
            }
            return perfCount;
        }
    }

    //var t = (from a in db.Theatres
    //         where a.Name.Contains("Mahen")
    //         select a).FirstOrDefault();           

    //var t2 = db.Theatres
    //            .Where(x => x.Name.Contains("Mahen"))
    //            .Include(x => x.Performances)
    //            .FirstOrDefault();
   


    public class Theatre
    {
        [Key]
        public int TheatreId { get; set; }

        [Required(ErrorMessage="Name is required")]
        [MaxLength(200,ErrorMessage="Maximum length for Name is 200 characters")]
        public string Name { get; set; }

        [MaxLength(200, ErrorMessage = "Maximum length for Address is 200 characters")]
        [MinLength(5, ErrorMessage="Minimum length is 5 characters.")]
        public string Address { get; set; }
        
        [MaxLength(15)]        
        public string Phone { get; set; }                
        public int Capacity { get; set; }
        public virtual List<Performance> Performances { get; set; }
    }

    public class Performance
    {
        public int PerformanceId { get; set; }

        [Required(ErrorMessage = "Name is required")]
        [MaxLength(250, ErrorMessage = "Maximum length for Name is 200 characters")]
        public string Name { get; set; }
        [MaxLength(500, ErrorMessage = "Maximum length for Description is 200 characters")]
        public string Description { get; set; }
        public Nullable<DateTime> Start { get; set; }
        public Nullable<decimal> Price { get; set; }
        public int TheatreId { get; set; }
        public virtual Theatre Theatre { get; set; }
    }

    public class NationatTheatreDBContext : DbContext
    {
        public DbSet<Theatre> Theatres { get; set; }
        public DbSet<Performance> Performances { get; set; }

        public NationatTheatreDBContext()
        {
            this.Database.Log = Console.WriteLine;
            //this.Configuration.LazyLoadingEnabled = false;
        }
          
    }        
}
