﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using NationalTheatreMVC4.Models;

namespace NationalTheatreMVC4.Controllers
{
    public class PerformancesController : Controller
    {
        private NationatTheatreDBContext db = new NationatTheatreDBContext();

        //
        // GET: /Performances/

        public ActionResult Index()
        {
            var performances = db.Performances.Include(p => p.Theatre);
            return View(performances.ToList());
        }

        //
        // GET: /Performances/Details/5

        public ActionResult Details(int id = 0)
        {
            Performance performance = db.Performances.Find(id);
            if (performance == null)
            {
                return HttpNotFound();
            }
            return View(performance);
        }

        //
        // GET: /Performances/Create

        public ActionResult Create()
        {
            ViewBag.TheatreId = new SelectList(db.Theatres, "TheatreId", "Name");
            return View();
        }

        //
        // POST: /Performances/Create

        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Create(Performance performance)
        {
            if (ModelState.IsValid)
            {
                db.Performances.Add(performance);
                db.SaveChanges();
                return RedirectToAction("Index");
            }

            ViewBag.TheatreId = new SelectList(db.Theatres, "TheatreId", "Name", performance.TheatreId);
            return View(performance);
        }

        //
        // GET: /Performances/Edit/5

        public ActionResult Edit(int id = 0)
        {
            Performance performance = db.Performances.Find(id);
            if (performance == null)
            {
                return HttpNotFound();
            }
            ViewBag.TheatreId = new SelectList(db.Theatres, "TheatreId", "Name", performance.TheatreId);
            return View(performance);
        }

        //
        // POST: /Performances/Edit/5

        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Edit(Performance performance)
        {
            if (ModelState.IsValid)
            {
                db.Entry(performance).State = EntityState.Modified;
                db.SaveChanges();
                return RedirectToAction("Index");
            }
            ViewBag.TheatreId = new SelectList(db.Theatres, "TheatreId", "Name", performance.TheatreId);
            return View(performance);
        }

        //
        // GET: /Performances/Delete/5

        public ActionResult Delete(int id = 0)
        {
            Performance performance = db.Performances.Find(id);
            if (performance == null)
            {
                return HttpNotFound();
            }
            return View(performance);
        }

        //
        // POST: /Performances/Delete/5

        [HttpPost, ActionName("Delete")]
        [ValidateAntiForgeryToken]
        public ActionResult DeleteConfirmed(int id)
        {
            Performance performance = db.Performances.Find(id);
            db.Performances.Remove(performance);
            db.SaveChanges();
            return RedirectToAction("Index");
        }

        protected override void Dispose(bool disposing)
        {
            db.Dispose();
            base.Dispose(disposing);
        }
    }
}