﻿using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.Data.Entity;
using System.Linq;
using System.Web;

namespace NationalTheatreMVC4.Models
{
    public class NationalTheatreManager : IDisposable
    {
        private NationatTheatreDBContext entities = new NationatTheatreDBContext();

        public NationalTheatreManager()
        {
            if (entities.Theatres.Count() == 0)
            {
                CreateSampleData();
            }
        }

        public void AddTheatre(Theatre t)
        {
            entities.Theatres.Add(t);
            entities.SaveChanges();
        }

        public Theatre FindTheatreById(int id)
        {
            return entities.Theatres.Find(id);
        }


        public IEnumerable<Performance> Search(string substr)
        {

            return entities.Performances
                        .Include("Theatre")
                        .Where(x => x.Name.Contains(substr))
                        .Take(10);
        }

        private void CreateSampleData()
        {           
            using (NationatTheatreDBContext db = new NationatTheatreDBContext())
            {                
                Theatre mahen = new Theatre();
                mahen.Name = "Mahenovo divadlo";
                mahen.Address = "Malinovského nám. 1";
                mahen.Phone = "789456123";
                mahen.Capacity = 350;

                db.Theatres.Add(mahen);
                db.SaveChanges();

                Performance p = new Performance();
                p.Name = "Králova řeč";
                p.Price = 400;
                p.Start = new DateTime(2014, 4, 22);
                p.Theatre = mahen;

                db.Performances.Add(p);

                Performance p2 = new Performance();
                p2.Name = "Jak je důležité míti Filipa";
                p2.Price = 350;
                p2.Start = new DateTime(2014, 4, 25);
                p2.Theatre = mahen;

                db.Performances.Add(p2);
                db.SaveChanges();
            }
        }
        

        public void Dispose()
        {
            Dispose(true);
            GC.SuppressFinalize(this);
        }

        protected virtual void Dispose(bool disposing)
        {
            if (disposing == true)
            {
                entities.Dispose();
            }
        }

        ~NationalTheatreManager()
        {
            Dispose(false);
        }
    }
    public class Theatre
    {
        [Key]
        public int TheatreId { get; set; }

        [Required(ErrorMessage = "Name is required")]
        [MaxLength(200, ErrorMessage = "Maximum length for Name is 200 characters")]
        public string Name { get; set; }

        [MaxLength(200, ErrorMessage = "Maximum length for Address is 200 characters")]
        [MinLength(5, ErrorMessage = "Minimum length is 5 characters.")]
        public string Address { get; set; }

        [MaxLength(15)]
        public string Phone { get; set; }
        public int Capacity { get; set; }
        public virtual List<Performance> Performances { get; set; }
    }

    public class Performance
    {
        public int PerformanceId { get; set; }

        [Required(ErrorMessage = "Name is required")]
        [MaxLength(250, ErrorMessage = "Maximum length for Name is 200 characters")]
        public string Name { get; set; }
        [MaxLength(500, ErrorMessage = "Maximum length for Description is 200 characters")]
        public string Description { get; set; }
        public Nullable<DateTime> Start { get; set; }
        public Nullable<decimal> Price { get; set; }
        public int TheatreId { get; set; }
        public virtual Theatre Theatre { get; set; }
    }

    public class NationatTheatreDBContext : DbContext
    {
        public DbSet<Theatre> Theatres { get; set; }
        public DbSet<Performance> Performances { get; set; }        
    }        
}